==> vokoscreen_1.9.0.orig.tar.gz: vokoscreen-1.9.0/language/vokoscreen_ast.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ast" version="2.0">
<context>
    <name>QvkMail</name>
    <message>
        <source>Mail last Video</source>
        <translation>Dunviar per corréu&apos;l vidéu caberu</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Dunviar per corréu ún o más videos esbillaos</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Dunviar</translation>
    </message>
    <message>
        <source>You find the Video as attachment</source>
        <translation>Pues alcontrar el vidéu como axuntu</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Esbilla unu o más ficheros</translation>
    </message>
</context>
<context>
    <name>QvkWebcam</name>
    <message>
        <source>Noborder</source>
        <translation>Ensin bordes</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Borde</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zarrar</translation>
    </message>
</context>
<context>
    <name>QvkWebcamController</name>
    <message>
        <source>Webcam</source>
        <translation>Cámara web</translation>
    </message>
    <message>
        <source>Device is busy</source>
        <translation>El preséu ta ocupáu</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation>Esbillar cámara web</translation>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Ventanu</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Fastera</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Lente</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audiu</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>ALSA</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Per defeutu</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Codec</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Nun grabar el mur</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Ruta&apos;l vidéu</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Reproductor</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>Vokoscreen minimizáu cuando la grabación entame</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Entamar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Aparar</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Posar</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Dunviar</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Tiempu de grabación</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>Grandor en KB</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>Grandor de pantalla al grabar</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formatu</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>Axustar FPS</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Abrir carpeta</translation>
    </message>
    <message>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Cuenta atrás</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Reproducir el vidéu caberu</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Dunviar vidéu</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>Esbilla un o más preseos</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>Cuadros per segundu d&apos;anguaño</translation>
    </message>
    <message>
        <source>Device %1 is busy</source>
        <translation>El preséu %1 ta ocupáu</translation>
    </message>
    <message>
        <source>Your Actual frames in the Settings is too heigh</source>
        <translation>Los tos frames d&apos;anguaño nos axustes son abondo altos</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>DIr</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Páxina d&apos;aniciu</translation>
    </message>
    <message>
        <source>Mailinglist</source>
        <translation>Lllista de corréu</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>Sofitu</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>Desendolcador</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Frames</translation>
    </message>
    <message>
        <source>Beta openSUSE</source>
        <translation>Beta openSUSE</translation>
    </message>
    <message>
        <source>Beta Ubuntu</source>
        <translation>Beta Ubuntu</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donar</translation>
    </message>
    <message>
        <source>Program for recording</source>
        <translation>Programa pa grabar</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Tornes</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Códigu fonte</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Amosar na bandexa&apos;l sistema</translation>
    </message>
    <message>
        <source>New version available</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> vokoscreen_2.0.0.orig.tar.gz: vokoscreen-2.0.0/language/vokoscreen_ast.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ast" version="2.0">
<context>
    <name>QvkMail</name>
    <message>
        <source>Mail last Video</source>
        <translation>Dunviar per corréu&apos;l vidéu caberu</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Dunviar per corréu ún o más videos esbillaos</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Dunviar</translation>
    </message>
    <message>
        <source>You find the Video as attachment</source>
        <translation>Pues alcontrar el vidéu como axuntu</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Esbilla unu o más ficheros</translation>
    </message>
</context>
<context>
    <name>QvkWebcam</name>
    <message>
        <source>Noborder</source>
        <translation>Ensin bordes</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Borde</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zarrar</translation>
    </message>
</context>
<context>
    <name>QvkWebcamController</name>
    <message>
        <source>Webcam</source>
        <translation>Cámara web</translation>
    </message>
    <message>
        <source>Device is busy</source>
        <translation>El preséu ta ocupáu</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation>Esbillar cámara web</translation>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Ventanu</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Fastera</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Lente</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audiu</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>ALSA</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Per defeutu</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Codec</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Nun grabar el mur</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Ruta&apos;l vidéu</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Reproductor</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>Vokoscreen minimizáu cuando la grabación entame</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Entamar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Aparar</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Posar</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Dunviar</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Tiempu de grabación</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>Grandor en KB</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>Grandor de pantalla al grabar</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formatu</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>Axustar FPS</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Abrir carpeta</translation>
    </message>
    <message>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Cuenta atrás</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Reproducir el vidéu caberu</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Dunviar vidéu</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>Esbilla un o más preseos</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>Cuadros per segundu d&apos;anguaño</translation>
    </message>
    <message>
        <source>Device %1 is busy</source>
        <translation>El preséu %1 ta ocupáu</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>DIr</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Páxina d&apos;aniciu</translation>
    </message>
    <message>
        <source>Mailinglist</source>
        <translation>Lllista de corréu</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>Sofitu</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>Desendolcador</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Frames</translation>
    </message>
    <message>
        <source>Beta openSUSE</source>
        <translation>Beta openSUSE</translation>
    </message>
    <message>
        <source>Beta Ubuntu</source>
        <translation>Beta Ubuntu</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donar</translation>
    </message>
    <message>
        <source>Program for recording</source>
        <translation>Programa pa grabar</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Tornes</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Códigu fonte</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Amosar na bandexa&apos;l sistema</translation>
    </message>
    <message>
        <source>New version available</source>
        <translation>Nueva versión disponible</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Codec vidéu</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Codec soníu</translation>
    </message>
</context>
</TS>
